//-*-c++-*-
#include "tulip/Int.h"
#include "tulip/SuperGraph.h"
#include "tulip/IntProxy.h"

Int::Int (const PropertyContext & context):Property<IntType , IntType>(context) {
  intProxy=(IntProxy *)context.propertyProxy;
}

